@@ -303,10 +303,15 @@ class trains_data_loader:
         self.train_y = pd.DataFrame()
         self.test_X = pd.DataFrame()
         self.test_y = pd.DataFrame()
+
+        trains_start_year = trains_start[0:4]
+        trains_end_year = trains_end[0:4]
+        test_start_year = test_start[0:4]
+        test_end_year = test_end[0:4]
         file_list = os.listdir(self.module_path + self.feature_dir)
         for index, file in enumerate(file_list):
             print(f"读取进度:{(index / len(file_list)) * 100}")
-            data = pd.read_csv(self.module_path + self.feature_dir + file)
+            data = pd.read_csv(self.module_path + self.feature_dir + file, encoding='utf-8')
 
             trains_x = data[(data['trade_date'] > trains_start) & (data['trade_date'] < trains_end)]
             trains_y = trains_x['flag']
